@@ -1,6 +1,6 @@
-var browserslist = require('../')
+let browserslist = require('../')
 
-var originUsage = browserslist.usage
+let originUsage = browserslist.usage
 
 beforeEach(() => {
   browserslist.usage = {
@@ -9,8 +9,14 @@ beforeEach(() => {
       'ie 9': 5,
       'ie 10': 10.1,
       'ie 11': 75
+    },
+    XX: {
+      'and_chr 0': 100
     }
   }
+  browserslist.data.and_chr = {
+    versions: ['80']
+  }
 })
 
 afterEach(() => {
@@ -48,13 +54,17 @@ it('fixes country case', () => {
 })
 
 it('loads country from Can I Use', () => {
-  expect(browserslist('> 1% in RU').length > 0).toBeTruthy()
+  expect(browserslist('> 1% in RU').length > 0).toBe(true)
 })
 
 it('loads continents from Can I Use', () => {
-  expect(browserslist('> 1% in alt-AS').length > 0).toBeTruthy()
+  expect(browserslist('> 1% in alt-AS').length > 0).toBe(true)
 })
 
 it('allows omission of the space between the > and the percentage', () => {
-  expect(browserslist('>10% in US').length > 0).toBeTruthy()
+  expect(browserslist('>10% in US').length > 0).toBe(true)
+})
+
+it('normalize incorrect caniuse versions for and_*', () => {
+  expect(browserslist('> 50% in XX')).toEqual(['and_chr 80'])
 })
