@@ -1,6 +1,7 @@
-var browserslist = require('../')
+let browserslist = require('../')
 
-var originData = browserslist.data
+let originData = browserslist.data
+let originWarn = console.warn
 
 beforeEach(() => {
   browserslist.data = {
@@ -8,16 +9,21 @@ beforeEach(() => {
       name: 'ie',
       versions: ['1', '2', '3'],
       releaseDate: {
-        '1': 0, // Thu, 01 Jan 1970 00:00:00 +0000
-        '2': 1483228800, // Sun, 01 Jan 2017 00:00:00 +0000
-        '3': 1485907200 // Wed, 01 Feb 2017 00:00:00 +0000
+        1: 0, // Thu, 01 Jan 1970 00:00:00 +0000
+        2: 1483228800, // Sun, 01 Jan 2017 00:00:00 +0000
+        3: 1485907200 // Wed, 01 Feb 2017 00:00:00 +0000
       }
     }
   }
+  console.warn = function (...args) {
+    if (args[0].includes('--update-db')) return
+    originWarn.apply(this, args)
+  }
 })
 
 afterEach(() => {
   browserslist.data = originData
+  console.warn = originWarn
 })
 
 it('selects versions released on year boundaries', () => {
